@@ -9,7 +9,11 @@ from lxml import etree
 import itertools
 from itertools import groupby
 import sys
-import urllib2
+
+try: # Python 3
+    from urllib.request import urlopen
+except ImportError: # Fallback Python 2.x
+    from urllib2 import urlopen
 
 
 class XMLStorage:
@@ -49,10 +53,10 @@ class Interaction(XMLStorage):
     def __init__(self, interaction_part):
         self.id = interaction_part.get('id')
         self.resnr = self.getdata(interaction_part, 'resnr')
-        self.restype = self.getdata(interaction_part, 'restype')
+        self.restype = self.getdata(interaction_part, 'restype', force_string=True)
         self.reschain = self.getdata(interaction_part, 'reschain', force_string=True)
         self.resnr_lig = self.getdata(interaction_part, 'resnr_lig')
-        self.restype_lig = self.getdata(interaction_part, 'restype_lig')
+        self.restype_lig = self.getdata(interaction_part, 'restype_lig', force_string=True)
         self.reschain_lig = self.getdata(interaction_part, 'reschain_lig', force_string=True)
         self.ligcoo = self.getcoordinates(interaction_part, 'ligcoo')
         self.protcoo = self.getcoordinates(interaction_part, 'protcoo')
@@ -83,8 +87,8 @@ class HydrogenBond(Interaction):
         self.protisdon = self.getdata(hbond_part, 'protisdon')
         self.donoridx = self.getdata(hbond_part, 'donoridx')
         self.acceptoridx = self.getdata(hbond_part, 'acceptoridx')
-        self.donortype = self.getdata(hbond_part, 'donortype')
-        self.acceptortype = self.getdata(hbond_part, 'acceptortype')
+        self.donortype = self.getdata(hbond_part, 'donortype', force_string=True)
+        self.acceptortype = self.getdata(hbond_part, 'acceptortype', force_string=True)
 
 
 class WaterBridge(Interaction):
@@ -101,8 +105,8 @@ class WaterBridge(Interaction):
 
         self.donor_idx = self.getdata(wbridge_part, 'donor_idx')
         self.acceptor_idx = self.getdata(wbridge_part, 'acceptor_idx')
-        self.donortype = self.getdata(wbridge_part, 'donortype')
-        self.acceptortype = self.getdata(wbridge_part, 'acceptortype')
+        self.donortype = self.getdata(wbridge_part, 'donortype', force_string=True)
+        self.acceptortype = self.getdata(wbridge_part, 'acceptortype', force_string=True)
         self.water_idx = self.getdata(wbridge_part, 'water_idx')
         self.watercoo = self.getcoordinates(wbridge_part, 'watercoo')
 
@@ -114,7 +118,7 @@ class SaltBridge(Interaction):
         Interaction.__init__(self, sbridge_part)
         self.dist =  self.getdata(sbridge_part, 'dist')
         self.protispos = self.getdata(sbridge_part, 'protispos')
-        self.lig_group = self.getdata(sbridge_part, 'lig_group')
+        self.lig_group = self.getdata(sbridge_part, 'lig_group', force_string=True)
         self.lig_idx_list = [int(tagpart.text) for tagpart in
                              sbridge_part.xpath('lig_idx_list/idx')]
 
@@ -153,8 +157,8 @@ class HalogenBond(Interaction):
         self.dist = self.getdata(halogen_part, 'dist')
         self.don_angle = self.getdata(halogen_part, 'don_angle')
         self.acc_angle = self.getdata(halogen_part, 'acc_angle')
-        self.donortype = self.getdata(halogen_part, 'donortype')
-        self.acceptortype = self.getdata(halogen_part, 'acceptortype')
+        self.donortype = self.getdata(halogen_part, 'donortype', force_string=True)
+        self.acceptortype = self.getdata(halogen_part, 'acceptortype', force_string=True)
         self.don_idx = self.getdata(halogen_part, 'don_idx')
         self.acc_idx = self.getdata(halogen_part, 'acc_idx')
         self.sidechain = self.getdata(halogen_part, 'sidechain')
@@ -166,14 +170,14 @@ class MetalComplex(Interaction):
     def __init__(self, metalcomplex_part):
         Interaction.__init__(self, metalcomplex_part)
         self.metal_idx = self.getdata(metalcomplex_part, 'metal_idx')
-        self.metal_type = self.getdata(metalcomplex_part, 'metal_type')
+        self.metal_type = self.getdata(metalcomplex_part, 'metal_type', force_string=True)
         self.target_idx = self.getdata(metalcomplex_part, 'target_idx')
-        self.target_type = self.getdata(metalcomplex_part, 'target_type')
+        self.target_type = self.getdata(metalcomplex_part, 'target_type', force_string=True)
         self.coordination = self.getdata(metalcomplex_part, 'coordination')
         self.dist = self.getdata(metalcomplex_part, 'dist')
-        self.location = self.getdata(metalcomplex_part, 'location')
+        self.location = self.getdata(metalcomplex_part, 'location', force_string=True)
         self.rms = self.getdata(metalcomplex_part, 'rms')
-        self.geometry = self.getdata(metalcomplex_part, 'geometry')
+        self.geometry = self.getdata(metalcomplex_part, 'geometry', force_string=True)
         self.complexnum = self.getdata(metalcomplex_part, 'complexnum')
         self.targetcoo = self.getcoordinates(metalcomplex_part, 'targetcoo')
         self.metalcoo = self.getcoordinates(metalcomplex_part, 'metalcoo')
@@ -186,10 +190,13 @@ class BSite(XMLStorage):
         self.pdbid = pdbid
         self.bsid = ":".join(bindingsite.xpath('identifiers/*/text()')[2:5])
         self.uniqueid = ":".join([self.pdbid, self.bsid])
-        self.hetid = self.getdata(bindingsite, 'identifiers/hetid')
-        self.longname = self.getdata(bindingsite, 'identifiers/longname')
-        self.ligtype = self.getdata(bindingsite, 'identifiers/ligtype')
-        self.smiles = self.getdata(bindingsite, 'identifiers/smiles')
+        self.hetid = self.getdata(bindingsite, 'identifiers/hetid', force_string=True)
+        self.longname = self.getdata(bindingsite, 'identifiers/longname', force_string=True)
+        self.ligtype = self.getdata(bindingsite, 'identifiers/ligtype', force_string=True)
+        self.smiles = self.getdata(bindingsite, 'identifiers/smiles', force_string=True)
+        self.inchikey = self.getdata(bindingsite, 'identifiers/inchikey', force_string=True)
+        self.position = self.getdata(bindingsite, 'identifiers/position')
+        self.chain = self.getdata(bindingsite, 'identifiers/chain', force_string=True)
 
         # Information on binding site members
         self.members = []
@@ -284,11 +291,7 @@ class PLIPXML(XMLStorage):
 
     def load_data(self, xmlfile):
         """Loads/parses an XML file and saves it as a tree if successful."""
-        try:
-            self.doc = etree.parse(xmlfile)
-        except IOError:
-            sys.__stderr__.write("XML %s file could not be read." % xmlfile)
-            sys.exit(1)
+        self.doc = etree.parse(xmlfile)
 
 class PLIPXMLREST(PLIPXML):
     """Parses and stores all from a PLIP XML file from the PLIP REST service"""
@@ -298,9 +301,5 @@ class PLIPXMLREST(PLIPXML):
     def load_data(self, pdbid):
         """Loads and parses an XML resource and saves it as a tree if successful"""
         #TODO Implement error handling
-        f = urllib2.urlopen("http://projects.biotec.tu-dresden.de/plip-rest/pdb/%s?format=xml" % pdbid.lower())
-        try:
-            self.doc = etree.parse(f)
-        except IOError:
-            sys.__stderr__.write("XML file for PDB ID %s could not be read." % pdbid)
-            sys.exit(1)
+        f = urlopen("http://projects.biotec.tu-dresden.de/plip-rest/pdb/%s?format=xml" % pdbid.lower())
+        self.doc = etree.parse(f)
