@@ -3,28 +3,34 @@ Protein-Ligand Interaction Profiler - Analyze and visualize protein-ligand inter
 report.py - Write PLIP results to output files.
 """
 
+# Compatibility
+from __future__ import print_function
+from __future__ import absolute_import
 
 # Python Standard Library
 import time
 from operator import itemgetter
 import sys
-import config
+
+# Own modules
+from . import config
 
 
 # External libraries
 import lxml.etree as et
 
-__version__ = '1.3.4'
+__version__ = '1.4.2'
 
 class StructureReport:
     """Creates reports (xml or txt) for one structure/"""
-    def __init__(self, mol):
+    def __init__(self, mol, outputprefix='report'):
         self.mol = mol
         self.excluded = self.mol.excluded
         self.xmlreport = self.construct_xml_tree()
         self.txtreport = self.construct_txt_file()
         self.get_bindingsite_data()
         self.outpath = mol.output_path
+        self.outputprefix = outputprefix
 
     def construct_xml_tree(self):
         """Construct the basic XML tree"""
@@ -50,7 +56,7 @@ class StructureReport:
         pdbfixes = et.SubElement(report, 'pdbfixes')
         pdbfixes.text = str(self.mol.information['pdbfixes'])
         filename = et.SubElement(report, 'filename')
-        filename.text = str(self.mol.sourcefiles['filename'])
+        filename.text = str(self.mol.sourcefiles.get('filename') or None)
         exligs = et.SubElement(report, 'excluded_ligands')
         for i, exlig in enumerate(self.excluded):
             e = et.SubElement(exligs, 'excluded_ligand', id=str(i + 1))
@@ -90,17 +96,23 @@ class StructureReport:
     def write_xml(self, as_string=False):
         """Write the XML report"""
         if not as_string:
-            et.ElementTree(self.xmlreport).write('%s/report.xml' % self.outpath, pretty_print=True, xml_declaration=True)
+            et.ElementTree(self.xmlreport).write('{}/{}.xml'.format(self.outpath, self.outputprefix), pretty_print=True, xml_declaration=True)
         else:
-            print et.tostring(self.xmlreport, pretty_print=True)
+            output = et.tostring(self.xmlreport, pretty_print=True)
+            if config.RAWSTRING:
+                output = repr(output)
+            print(output)
 
     def write_txt(self, as_string=False):
         """Write the TXT report"""
         if not as_string:
-            with open('%s/report.txt' % self.outpath, 'w') as f:
+            with open('{}/{}.txt'.format(self.outpath, self.outputprefix), 'w') as f:
                 [f.write(textline + '\n') for textline in self.txtreport]
         else:
-            print '\n'.join(self.txtreport)
+            output = '\n'.join(self.txtreport)
+            if config.RAWSTRING:
+                output = repr(output)
+            print(output)
 
 
 class BindingSiteReport:
@@ -350,6 +362,7 @@ class BindingSiteReport:
         composite = et.SubElement(identifiers, 'composite')
         members = et.SubElement(identifiers, 'members')
         smiles = et.SubElement(identifiers, 'smiles')
+        inchikey = et.SubElement(identifiers, 'inchikey')
 
         # Ligand properties. Number of (unpaired) functional atoms and rings.
         lig_properties = et.SubElement(report, 'lig_properties')
@@ -391,6 +404,7 @@ class BindingSiteReport:
         longname.text = self.longname
         ligtype.text = self.ligtype
         smiles.text = self.ligand.smiles
+        inchikey.text = self.ligand.inchikey
         num_heavy_atoms.text = str(self.ligand.heavy_atoms)  # Number of heavy atoms in ligand
         for i, member in enumerate(self.lig_members):
             bsid = ":".join(str(element) for element in member)
